SEISMON
=======

Monitors and summarises global seismic information and its possible effect on the Laser Interferomerer Gravitational-wave Observatory (LIGO) instrumental sites

## Related Publications
1. **Michael Coughlin et al 2017 Class. Quantum Grav. 34 044004** [10.1088/1361-6382/aa5a60](https://doi.org/10.1088/1361-6382/aa5a60)
2. **Nikhil Mukund et al 2019 Class. Quantum Grav. 36 085005** [10.1088/1361-6382/ab0d2c](https://doi.org/10.1088/1361-6382/ab0d2c)           
3. **Eyal Schwartz et al 2020 Class. Quantum Grav.  37 235007** [10.1088/1361-6382/aa5a60](https://doi.org/10.1088/1361-6382/abbc8c)
